# UserPermission

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**permission_role** | [**Role**](Role.md) |  | 
**role** | **str** |  | 
**user_email** | **str** |  | 
**user_id** | **str** |  | 
**user_picture** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


